@@ -166,15 +166,15 @@ class Interface(Data):
     @property
     def resultantforce(self):
         if not self.forces:
-            return
+            return []
         frame = self.frame
         w, u, v = frame.zaxis, frame.xaxis, frame.yaxis
         normalcomponents = [f["c_np"] - f["c_nn"] for f in self.forces]
         sum_n = sum(normalcomponents)
         sum_u = sum(f["c_u"] for f in self.forces)
         sum_v = sum(f["c_v"] for f in self.forces)
-        position = centroid_points_weighted(self.points, normalcomponents)
+        position = Point(*centroid_points_weighted(self.points, normalcomponents))
         forcevector = (w * sum_n + u * sum_u + v * sum_v) * 0.5
         p1 = position + forcevector
         p2 = position - forcevector
-        return Line(p1, p2)
+        return [Line(p1, p2)]
